{'message_key': {'someParameters': ['just', 'a', 'message', 'key', 'nbd']}, 'success': True, 'result': {'first': {'message_key': {'someParameters': ['just', 'a', 'message', 'key', 'nbd']}, 'success': False, 'result': None, 'error': ['  File "/var/task/handler.py", line 41, in handler\n    raise Exception("Whoops!")\n', 'Exception: Whoops!'], 'error_origin': 'system', 'start_time': '2021-09-03T00:10:34.261302+00:00', 'duration_seconds': -1}, 'second': {'message_key': {'someParameters': ['just', 'a', 'message', 'key', 'nbd']}, 'success': False, 'result': None, 'error': ['  File "/var/task/handler.py", line 41, in handler\n    raise Exception("Whoops!")\n', 'Exception: Whoops!'], 'error_origin': 'system', 'start_time': '2021-09-03T00:10:34.261302+00:00', 'duration_seconds': -1}, 'tenth': {'message_key': {'someParameters': ['just', 'a', 'message', 'key', 'nbd']}, 'success': False, 'result': None, 'error': ['  File "/var/task/handler.py", line 41, in handler\n    raise Exception("Whoops!")\n', 'Exception: Whoops!'], 'error_origin': 'system', 'start_time': '2021-09-03T00:10:34.261302+00:00', 'duration_seconds': -1}, 'twentieth': {'message_key': {'someParameters': ['just', 'a', 'message', 'key', 'nbd']}, 'success': False, 'result': None, 'error': ['  File "/var/task/handler.py", line 41, in handler\n    raise Exception("Whoops!")\n', 'Exception: Whoops!'], 'error_origin': 'system', 'start_time': '2021-09-03T00:10:34.261302+00:00', 'duration_seconds': -1}}, 'error': None, 'error_origin': None, 'start_time': '2021-09-03T00:10:34.261302+00:00', 'duration_seconds': 0.32, 'runtime_info': None}